@@ -64,39 +64,83 @@ import java.util.Map;
  * when it is closed and doesn't allow any calls after it got closed. Additionally the
  * EncapsulatedException performs a check on close() if the Connection is autoCommit==true, and
  * throws an IllegalStateException if it is not.
- * 
+ *
  * @author afe
  *
  */
 public class EncapsulatedConnection {
+
+    /** The nature of the underlying connection */
+    public static enum Nature {
+        /**
+         * Signals a read-only connection.
+         */
+        READ_ONLY,
+        /**
+         * Signals a read-write connection.
+         */
+        READ_WRITE,
+        /**
+         * Signals a read-write connection w/o a timeout.
+         */
+        NO_TIMEOUT;
+    }
+
+    // ------------------------------------------------------------------------------------------------------------- //
+
 	private final Connection _connection;
 	private final int _contextID;
-	private final boolean _readOnly;
+	private final Nature _mode;
 	private final DatabaseAccess _dbAccess;
 	private boolean _closed = false;
 	private boolean _isAutoCommit = true;
 
+	/**
+	 * Initializes a new {@link EncapsulatedConnection}.
+	 */
 	public EncapsulatedConnection(DatabaseAccess dbAccess, Connection connection, int contextID, boolean readOnly) {
-		_dbAccess = dbAccess;
-		_connection = connection;
-		_contextID = contextID;
-		_readOnly = readOnly;
+		this(dbAccess, connection, contextID, readOnly ? Nature.READ_ONLY : Nature.READ_WRITE);
 	}
 
+	/**
+     * Initializes a new {@link EncapsulatedConnection}.
+     */
+    public EncapsulatedConnection(DatabaseAccess dbAccess, Connection connection, int contextID, Nature mode) {
+        super();
+        _dbAccess = dbAccess;
+        _connection = connection;
+        _contextID = contextID;
+        _mode = mode;
+    }
+
 	public void clearWarnings() throws SQLException {
 		checkNotClosed();
 		_connection.clearWarnings();
 	}
 
 	public void close() throws SQLException, StorageAccessException {
-		if (!_isAutoCommit)
-			throw new IllegalStateException("Closing connection while autoCommit==false");
+		if (!_isAutoCommit) {
+            throw new IllegalStateException("Closing connection while autoCommit==false");
+        }
 		checkNotClosed();
 		_closed = true;
-		if (_readOnly)
-		    _dbAccess.backReadOnly(_contextID, _connection);
-		else
-		    _dbAccess.backWritable(_contextID, _connection);
+		switch (_mode) {
+            case READ_ONLY:
+                _dbAccess.backReadOnly(_contextID, _connection);
+                break;
+            case READ_WRITE:
+                _dbAccess.backWritable(_contextID, _connection);
+                break;
+            case NO_TIMEOUT:
+                if (_dbAccess instanceof DatabaseAccessWithNoTimeoutSupport) {
+                    ((DatabaseAccessWithNoTimeoutSupport) _dbAccess).backNoTimeout(_contextID, _connection);
+                } else {
+                    _dbAccess.backWritable(_contextID, _connection);
+                }
+                break;
+            default:
+                throw new IllegalStateException("Unknown mode: " + _mode.name());
+        }
 	}
 
 	public void commit() throws SQLException {
@@ -274,7 +318,8 @@ public class EncapsulatedConnection {
 	}
 
 	private void checkNotClosed() throws SQLException {
-		if (_closed)
-			throw new SQLException("Connection closed");
+		if (_closed) {
+            throw new SQLException("Connection closed");
+        }
 	}
 }
