@@ -135,11 +135,14 @@ public class MailContentTypeTransferHandlerImpl extends AbstractTransferHandler
     
     private final int _sourceFieldIndex;
 
+    private final int _nestedMsgsFieldIndex;
+
     public MailContentTypeTransferHandlerImpl(MailContentType contentType, OXJSONAccess ajaxAccess) {
         super(contentType, ajaxAccess);
         _idIndex = getFieldIndex(MailConstants.FIELD_ID);
         _receivedDateIndex = getFieldIndex(MailConstants.RECEIVED_DATE);
         _sourceFieldIndex = getFieldIndex(MailConstants.SOURCE);
+        _nestedMsgsFieldIndex = getFieldIndex(MailConstants.NESTED_MSGS);
         _getAllBitSet.set(_idIndex);
         _getAllBitSet.set(_receivedDateIndex);
     }
@@ -408,10 +411,12 @@ public class MailContentTypeTransferHandlerImpl extends AbstractTransferHandler
         parameters.put(UNSEEN, ONE);
         parameters.put(VIEW, RAW);
         if("EAS".equals(object.getSession().getProtocol())){
-            parameters.put(ATTACH_SRC, ONE);
+            if (requestedFields.get(_sourceFieldIndex)) {
+                parameters.put(ATTACH_SRC, ONE);
+            }
             BitSet extendedFields = new BitSet();
             extendedFields.or(requestedFields);
-            extendedFields.set(_sourceFieldIndex);
+            extendedFields.set(_nestedMsgsFieldIndex);
             requestedFields = extendedFields;
         }
         readDataObject(object, requestedFields, parameters);
