@@ -64,7 +64,7 @@ import com.openexchange.usm.database.ox.USMUpdateTaskProvider;
 /**
  * {@link USMCreatePrimaryKeyUpdateTask} Replaces unique index with primary key for those USM table for which the primary key was missing.
  * Adds primary key or removes unique index if a previous execution was partially successful.
- * 
+ *
  * @author <a href="mailto:afe@microdoc.de">Alexander Feess</a>
  */
 public class USMCreatePrimaryKeyUpdateTask extends USMBaseUpdateTaskV2 {
@@ -103,11 +103,9 @@ public class USMCreatePrimaryKeyUpdateTask extends USMBaseUpdateTaskV2 {
 
     @Override
     protected void doPerform(PerformParameters params) throws OXException {
-        int contextId = params.getContextId();
-        Connection con = null;
+        Connection con = params.getConnection();
         Statement stmt = null;
         try {
-            con = _provider.getDatabaseService().getForUpdateTask(contextId);
             con.setAutoCommit(false);
             for (PrimaryKeyMappingInfo info : _TABLES_WITHOUT_PRIMARY_KEY) {
                 stmt = dropIndexAndAddPrimaryKey(con, stmt, info);
@@ -118,8 +116,6 @@ public class USMCreatePrimaryKeyUpdateTask extends USMBaseUpdateTaskV2 {
             throw USMUpdateExceptionCodes.SQL_ERROR.create(e);
         } finally {
             enableAutocommit(con, stmt);
-            if (con != null)
-                _provider.getDatabaseService().backWritable(contextId, con);
         }
     }
 
@@ -127,8 +123,9 @@ public class USMCreatePrimaryKeyUpdateTask extends USMBaseUpdateTaskV2 {
         Set<String> indexes = USMBaseUpdateTaskV2.getTableIndexes(info._tableName, con);
         String alterTableOperations = buildAlterTableOperations(info, Tools.hasPrimaryKey(con, info._tableName), indexes);
         if (alterTableOperations != null) {
-            if (stmt == null)
+            if (stmt == null) {
                 stmt = con.createStatement();
+            }
             String alterTableStatement = "ALTER TABLE " + info._tableName + ' ' + alterTableOperations;
             LOG.debug(alterTableStatement);
             stmt.execute(alterTableStatement);
@@ -138,12 +135,14 @@ public class USMCreatePrimaryKeyUpdateTask extends USMBaseUpdateTaskV2 {
 
     private static String buildAlterTableOperations(PrimaryKeyMappingInfo info, boolean hasPrimaryKey, Set<String> indexes) {
         if (indexes.contains(info._indexName)) {
-            if (hasPrimaryKey)
+            if (hasPrimaryKey) {
                 return "DROP INDEX " + info._indexName;
+            }
             return "ADD PRIMARY KEY(" + info._primaryKeyColumns + "), DROP INDEX " + info._indexName;
         }
-        if (!hasPrimaryKey)
+        if (!hasPrimaryKey) {
             return "ADD PRIMARY KEY(" + info._primaryKeyColumns + ')';
+        }
         return null;
     }
 }
