@@ -167,8 +167,8 @@ public abstract class NormalCommandHandler extends BaseCommandHandler {
         for (DataObject changeException : exceptions) {
             boolean existsInDeleteExceptions = false;
             for (int i = 0; deleteExceptions != null && i < deleteExceptions.length(); i++) {
-				if (changeException.getFieldContent(CommonCalendarTasksFieldNames.RECURRENCE_DATE_POSITION).equals(
-						deleteExceptions.get(i)))
+                Object obj = changeException.getFieldContent(CommonCalendarTasksFieldNames.RECURRENCE_DATE_POSITION);
+				if (obj != null && obj.equals(deleteExceptions.get(i)))
                     existsInDeleteExceptions = true;
             }
             if (!existsInDeleteExceptions) {
